==> maepygallery-qml_0.3.0-2.tar.gz: maepygallery-qml-0.3.0/src/opt/maepygalleryqml/script.js <==
//function bla() {
//  console.log("blabla");
//}
var i = 0;
WorkerScript.onMessage = function(mes) {
  if(mes.action == "delete"){
    mes.th.clear();
    mes.th.sync();
  }else if(mes.action == "markToDelete"){
    console.log(mes.th.get(mes.index).toDelete)
    var b = mes.th.get(mes.index).toDelete;
    if(mes.th.get(mes.index).toDelete) {
//      mes.th.setProperty(mes.index, "toDelete", false)
      b = false;
//      mes.th.sync(); 
    }else{ 
//      mes.th.setProperty(mes.index, "toDelete", true)
      b = true; 
//      mes.th.sync();
    }
    var data = {"name": mes.st, "colorCode":"pink", "index": mes.index, "sourceThumb":mes.st, "sourceFullImage": mes.sfi, "makeTime": mes.mkt, "modifyTime": mes.mt, "fileSize": mes.fs, "toDelete": b };
    mes.th.remove(mes.index);
//    mes.th.sync();
    mes.th.insert(mes.index, data);
    mes.th.sync();
//    WorkerScript.sendMessage( { action: "refresh", th: mes.th, "index": mes.index } );
  }else if(mes.action == "unSelectAll"){
    var i = 0;
    for(i=0;i<mes.th.count;i++){
      mes.th.get(i).toDelete?mes.th.get(i).toDelete = false:i=i;
      mes.th.sync();
    }
    console.log("unselected all");
    WorkerScript.sendMessage( { action: "refresh", th: mes.th, "index": 0 } );
  
  }else if(mes.action == "sort"){
    var i = 0;
    var j = 0;
    for(i=1;i<mes.th.count;i++){
//      var g = mes.th.get(i-1).makeTime;
      for(j=1;j<mes.th.count;j++){
        if(parseInt(mes.th.get(i-1).makeTime)>parseInt(mes.th.get(j).makeTime)) {
//          console.log(mes.th.get(i-1).makeTime);
//          console.log(parseInt(mes.th.get(j).makeTime));
          mes.th.move(i-1,j,1);
//          mes.th.sync();
        }
      }
      mes.th.sync();
    }
//    mes.th.sync();
  }else{
    var data = {"name": mes.st, "colorCode":"pink", "index": mes.index, "sourceThumb":mes.st, "sourceFullImage": mes.sfi, "makeTime": mes.mkt, "modifyTime": mes.mt, "fileSize": mes.fs, "toDelete": mes.toDelete };
    mes.th.append(data);
    mes.th.sync();
//    console.log(mes.th.count)
    WorkerScript.sendMessage( { action: "add", th: mes.th, "index": mes.index } );
  }
  //wykonuj za kazdym razem zliczenie ile plikow do skasowania
  var h = 0;
  for(i=0;i<mes.th.count;i++){
      mes.th.get(i).toDelete?h++:h=h;
  }
  WorkerScript.sendMessage({ action: "hmtd", hmtd: h , th: mes.th})
}

==> maepygallery-qml_0.3.3-0.tar.gz: maepygallery-qml-0.3.3/src/opt/maepygalleryqml/script.js <==
//function bla() {
//  console.log("blabla");
//}
var i = 0;
WorkerScript.onMessage = function(mes) {
  if(mes.action == "delete"){
    mes.th.clear();
    mes.th.sync();
  }else if(mes.action == "markToDelete"){
    console.log(mes.th.get(mes.index).toDelete)
    var b = mes.th.get(mes.index).toDelete;
    if(mes.th.get(mes.index).toDelete) {
//      mes.th.setProperty(mes.index, "toDelete", false)
      b = false;
//      mes.th.sync(); 
    }else{ 
//      mes.th.setProperty(mes.index, "toDelete", true)
      b = true; 
//      mes.th.sync();
    }
    var data = {"name": mes.st, "colorCode":"pink", "index": mes.index, "sourceThumb":mes.st, "sourceFullImage": mes.sfi, "makeTime": mes.mkt, "modifyTime": mes.mt, "fileSize": mes.fs, "toDelete": b };
    mes.th.remove(mes.index);
//    mes.th.sync();
    mes.th.insert(mes.index, data);
    mes.th.sync();
//    WorkerScript.sendMessage( { action: "refresh", th: mes.th, "index": mes.index } );
  }else if(mes.action == "unSelectAll"){
    var i = 0;
    for(i=0;i<mes.th.count;i++){
      mes.th.get(i).toDelete?mes.th.get(i).toDelete = false:i=i;
      mes.th.sync();
    }
    console.log("unselected all");
    WorkerScript.sendMessage( { action: "refresh", th: mes.th, "index": 0 } );
  
  }else if(mes.action == "getIndexes"){
    var i = 0;
    var h = 0;
    for(i=0;i<mes.th.count;i++) {
      mes.th.get(i).toDelete?h=h+i+" ":h=h;
    }
    console.log("marked indexes" + h);
//    console.log("unselected all");
    WorkerScript.sendMessage( { action: "getIndexList", th: mes.th, "indexList": h } );
  
  }else if(mes.action == "sort"){
    var i = 0;
    var j = 0;
    for(i=1;i<mes.th.count;i++){
//      var g = mes.th.get(i-1).makeTime;
      for(j=1;j<mes.th.count;j++){
        if(parseInt(mes.th.get(i-1).makeTime)>parseInt(mes.th.get(j).makeTime)) {
//          console.log(mes.th.get(i-1).makeTime);
//          console.log(parseInt(mes.th.get(j).makeTime));
          mes.th.move(i-1,j,1);
//          mes.th.sync();
        }
      }
      mes.th.sync();
    }
  }else{
    var data = {"name": mes.st, "colorCode":"pink", "index": mes.index, "sourceThumb":mes.st, "sourceFullImage": mes.sfi, "makeTime": mes.mkt, "modifyTime": mes.mt, "fileSize": mes.fs, "toDelete": mes.toDelete };
    mes.th.append(data);
    mes.th.sync();
    WorkerScript.sendMessage( { action: "add", th: mes.th, "index": mes.index } );
  }
  //wykonuj za kazdym razem zliczenie ile plikow do skasowania
  var h = 0;
  for(i=0;i<mes.th.count;i++){
      mes.th.get(i).toDelete?h++:h=h;
  }
  WorkerScript.sendMessage({ action: "hmtd", hmtd: h , th: mes.th})
}
